/**
 * Copyright (c) 2022, Salesforce, Inc.,
 * All rights reserved.
 * For full license text, see the LICENSE.txt file
 */

import { RECORD_ID_PREFIX, RECORD_FIELDS_KEY_JUNCTION } from '@salesforce/lds-adapters-uiapi';
export { API_NAMESPACE, RECORD_ID_PREFIX, RECORD_REPRESENTATION_NAME, RECORD_VIEW_ENTITY_ID_PREFIX, buildRecordRepKeyFromId, extractRecordIdFromStoreKey, isStoreKeyRecordViewEntity } from '@salesforce/lds-adapters-uiapi';

function isStoreKeyRecordId(key) {
    return key.indexOf(RECORD_ID_PREFIX) > -1 && key.indexOf(RECORD_FIELDS_KEY_JUNCTION) === -1;
}
function isStoreKeyRecordField(key) {
    return key.indexOf(RECORD_ID_PREFIX) > -1 && key.indexOf(RECORD_FIELDS_KEY_JUNCTION) > -1;
}
function buildRecordFieldStoreKey(recordKey, fieldName) {
    return `${recordKey}${RECORD_FIELDS_KEY_JUNCTION}${fieldName}`;
}
function objectsDeepEqual(lhs, rhs) {
    if (lhs === rhs)
        return true;
    if (typeof lhs !== 'object' || typeof rhs !== 'object' || lhs === null || rhs === null)
        return false;
    const lhsKeys = Object.keys(lhs);
    const rhsKeys = Object.keys(rhs);
    if (lhsKeys.length !== rhsKeys.length)
        return false;
    for (let key of lhsKeys) {
        if (!rhsKeys.includes(key))
            return false;
        if (typeof lhs[key] === 'function' || typeof rhs[key] === 'function') {
            if (lhs[key].toString() !== rhs[key].toString())
                return false;
        }
        else {
            if (!objectsDeepEqual(lhs[key], rhs[key]))
                return false;
        }
    }
    return true;
}

export { buildRecordFieldStoreKey, isStoreKeyRecordField, isStoreKeyRecordId, objectsDeepEqual };
